@@ -64,9 +64,9 @@ public:
     {
       return m_buffer;
     }
-  void set_buffer(const Glib::RefPtr<NoteBuffer> & b);
-  virtual const Glib::ustring & text() override;
-  virtual void set_text(const Glib::ustring & t) override;
+  void set_buffer(Glib::RefPtr<NoteBuffer> && b);
+  const Glib::ustring & text() override;
+  void set_text(Glib::ustring && t) override;
 
 private:
   void invalidate_text();
@@ -96,32 +96,25 @@ public:
   ~Note();
 
 
-  static Note::Ptr create_new_note(const Glib::ustring & title,
-                                   const Glib::ustring & filename,
-                                   NoteManager & manager,
-                                   IGnote & g);
+  static Note::Ptr create_new_note(Glib::ustring && title, Glib::ustring && filename, NoteManager & manager, IGnote & g);
 
-  static Note::Ptr create_existing_note(std::unique_ptr<NoteData> data,
-                                        Glib::ustring filepath,
-                                        NoteManager & manager,
-                                        IGnote & g);
+  static Note::Ptr create_existing_note(std::unique_ptr<NoteData> data, Glib::ustring && filepath, NoteManager & manager, IGnote & g);
 
-  Note(std::unique_ptr<NoteData> _data, const Glib::ustring & filepath, NoteManager & manager, IGnote & g);
+  Note(std::unique_ptr<NoteData> _data, Glib::ustring && filepath, NoteManager & manager, IGnote & g);
   virtual void delete_note() override;
-  static Note::Ptr load(const Glib::ustring &, NoteManager &, IGnote &);
+  static Note::Ptr load(Glib::ustring &&, NoteManager &, IGnote &);
   virtual void save() override;
   virtual void queue_save(ChangeType c) override;
   using NoteBase::remove_tag;
   virtual void remove_tag(Tag &) override;
-  void add_child_widget(const Glib::RefPtr<Gtk::TextChildAnchor> & child_anchor,
-                        Gtk::Widget * widget);
+  void add_child_widget(Glib::RefPtr<Gtk::TextChildAnchor> && child_anchor, Gtk::Widget *widget);
 
   using NoteBase::set_title;
-  virtual void set_title(const Glib::ustring & new_title, bool from_user_action) override;
-  virtual void rename_without_link_update(const Glib::ustring & newTitle) override;
-  virtual void set_xml_content(const Glib::ustring & xml) override;
+  void set_title(Glib::ustring && new_title, bool from_user_action) override;
+  void rename_without_link_update(Glib::ustring && newTitle) override;
+  void set_xml_content(Glib::ustring && xml) override;
   virtual Glib::ustring text_content() override;
-  void set_text_content(const Glib::ustring & text);
+  void set_text_content(Glib::ustring && text);
 
   const Glib::RefPtr<NoteTagTable> & get_tag_table();
   bool has_buffer() const
@@ -187,9 +180,8 @@ private:
 
   struct ChildWidgetData
   {
-    ChildWidgetData(const Glib::RefPtr<Gtk::TextChildAnchor> & _anchor,
-                    Gtk::Widget *_widget)
-      : anchor(_anchor)
+    ChildWidgetData(Glib::RefPtr<Gtk::TextChildAnchor> && _anchor, Gtk::Widget *_widget)
+      : anchor(std::move(_anchor))
       , widget(_widget)
       {
       }
