@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2014,2017,2019-2020 Aurimas Cernius
+ * Copyright (C) 2010-2014,2017,2019-2020,2022 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -74,14 +74,11 @@ namespace gnote {
   protected:
     virtual void post_load() override;
     virtual void migrate_notes(const Glib::ustring & old_note_dir) override;
-    virtual NoteBase::Ptr create_note_from_template(const Glib::ustring & title,
-                                                    const NoteBase::Ptr & template_note,
-                                                    const Glib::ustring & guid) override;
-    virtual NoteBase::Ptr create_note(Glib::ustring title, Glib::ustring body, const Glib::ustring & guid = Glib::ustring()) override;
-    virtual NoteBase::Ptr create_new_note(const Glib::ustring & title, const Glib::ustring & xml_content,
-                                          const Glib::ustring & guid) override;
-    virtual NoteBase::Ptr note_create_new(const Glib::ustring & title, const Glib::ustring & file_name) override;
-    virtual NoteBase::Ptr note_load(const Glib::ustring & file_name) override;
+    NoteBase::Ptr create_note_from_template(Glib::ustring && title, const NoteBase::Ptr & template_note, Glib::ustring && guid) override;
+    NoteBase::Ptr create_note(Glib::ustring && title, Glib::ustring && body, Glib::ustring && guid = Glib::ustring()) override;
+    NoteBase::Ptr create_new_note(Glib::ustring && title, Glib::ustring && xml_content, Glib::ustring && guid) override;
+    virtual NoteBase::Ptr note_create_new(Glib::ustring && title, Glib::ustring && file_name) override;
+    NoteBase::Ptr note_load(Glib::ustring && file_name) override;
   private:
     AddinManager *create_addin_manager();
     void create_start_notes();
