@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011,2013-2014,2017 Aurimas Cernius
+ * Copyright (C) 2011,2013-2014,2017,2019 Aurimas Cernius
  * Copyright (C) 2010 Debarshi Ray
  *
  * This program is free software: you can redistribute it and/or modify
@@ -28,11 +28,13 @@
 #include <gtkmm/radiobutton.h>
 #include <gtkmm/treeview.h>
 
-#include "base/macros.hpp"
 #include "note.hpp"
 
 namespace gnote {
 
+class IGnote;
+
+
 // Values should match with those in data/gnote.schemas.in
 enum NoteRenameBehavior {
   NOTE_RENAME_ALWAYS_SHOW_DIALOG = 0,
@@ -76,11 +78,12 @@ class NoteRenameDialog
 {
 public:
 
-  typedef shared_ptr<std::map<NoteBase::Ptr, bool> > MapPtr;
+  typedef std::shared_ptr<std::map<NoteBase::Ptr, bool> > MapPtr;
 
   NoteRenameDialog(const NoteBase::List & notes,
                    const Glib::ustring & old_title,
-                   const NoteBase::Ptr & renamed_note);
+                   const NoteBase::Ptr & renamed_note,
+                   IGnote & g);
   MapPtr get_notes() const;
   NoteRenameBehavior get_selected_behavior() const;
 
@@ -101,6 +104,7 @@ private:
   void on_select_all_button_clicked(bool select);
   void on_toggle_cell_toggled(const Glib::ustring & p);
 
+  IGnote & m_gnote;
   ModelColumnRecord m_model_column_record;
   Glib::RefPtr<Gtk::ListStore> m_notes_model;
   Gtk::Button m_dont_rename_button;
