@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011-2013,2015-2017,2019 Aurimas Cernius
+ * Copyright (C) 2011-2013,2015-2017,2019-2020 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -73,7 +73,8 @@ private:
   void on_save_sync_addin_button();
   void on_sync_settings_saved(bool saved, Glib::ustring errorMsg);
 
-  void on_preferences_setting_changed(const Glib::ustring & key);
+  void on_note_rename_behavior_changed();
+  void on_autosync_timeout_setting_changed();
   void on_rename_behavior_changed();
 
   Glib::ustring get_selected_addin();
