@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2021 Aurimas Cernius
+ * Copyright (C) 2010-2022 Aurimas Cernius
  * Copyright (C) 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -154,6 +154,17 @@ namespace gnote {
                                 GDK_KEY_W, Gdk::CONTROL_MASK, (Gtk::AccelFlags)0);
     m_keybinder.add_accelerator(sigc::mem_fun(*this, &NoteRecentChanges::close_window),
                                 GDK_KEY_Q, Gdk::CONTROL_MASK, (Gtk::AccelFlags)0);
+    m_keybinder.add_accelerator(sigc::mem_fun(*this, &NoteRecentChanges::next_tab),
+                                GDK_KEY_Page_Down, Gdk::CONTROL_MASK, (Gtk::AccelFlags)0);
+    m_keybinder.add_accelerator(sigc::mem_fun(*this, &NoteRecentChanges::previous_tab),
+                                GDK_KEY_Page_Up, Gdk::CONTROL_MASK, (Gtk::AccelFlags)0);
+    {
+      auto show_shortcuts = m_gnote.action_manager().get_app_action("help-shortcuts");
+      if(show_shortcuts) {
+        m_keybinder.add_accelerator([show_shortcuts=std::move(show_shortcuts)]{ show_shortcuts->activate(); },
+                                    GDK_KEY_question, Gdk::CONTROL_MASK, (Gtk::AccelFlags)0);
+      }
+    }
   }
 
 
@@ -181,24 +192,22 @@ namespace gnote {
   void NoteRecentChanges::register_actions()
   {
     auto & am = m_gnote.action_manager();
-    std::map<Glib::ustring, const Glib::VariantType*> actions = am.get_main_window_actions();
-    for(std::map<Glib::ustring, const Glib::VariantType*>::iterator iter = actions.begin();
-        iter != actions.end(); ++iter) {
+    for(auto & action_def : am.get_main_window_actions()) {
       MainWindowAction::Ptr action;
-      if(iter->second == NULL) {
-        add_action(action = MainWindowAction::create(iter->first));
+      if(action_def.second == NULL) {
+        add_action(action = MainWindowAction::create(Glib::ustring(action_def.first)));
       }
-      else if(iter->second == &Glib::Variant<bool>::variant_type()) {
-        add_action(action = MainWindowAction::create(iter->first, false));
+      else if(action_def.second == &Glib::Variant<bool>::variant_type()) {
+        add_action(action = MainWindowAction::create(Glib::ustring(action_def.first), false));
       }
-      else if(iter->second == &Glib::Variant<gint32>::variant_type()) {
-        add_action(action = MainWindowAction::create(iter->first, 0));
+      else if(action_def.second == &Glib::Variant<gint32>::variant_type()) {
+        add_action(action = MainWindowAction::create(Glib::ustring(action_def.first), 0));
       }
-      else if(iter->second == &Glib::Variant<Glib::ustring>::variant_type()) {
-        add_action(action = MainWindowAction::create(iter->first, Glib::ustring("")));
+      else if(action_def.second == &Glib::Variant<Glib::ustring>::variant_type()) {
+        add_action(action = MainWindowAction::create(Glib::ustring(action_def.first), Glib::ustring("")));
       }
       if(action) {
-        action->is_modifying(am.is_modifying_main_window_action(iter->first));
+        action->is_modifying(am.is_modifying_main_window_action(action_def.first));
       }
     }
     find_action("close-window")->signal_activate()
@@ -273,8 +282,13 @@ namespace gnote {
     m_search_button.signal_toggled().connect(sigc::mem_fun(*this, &NoteRecentChanges::on_search_button_toggled));
     m_search_button.add_accelerator("activate", m_accel_group, GDK_KEY_F, Gdk::CONTROL_MASK, (Gtk::AccelFlags) 0);
     m_search_button.set_tooltip_text(_("Search"));
-    m_search_button.show_all();
-    right_box->attach(m_search_button, right_box_pos++, 0, 1, 1);
+    Gtk::Grid *search_group = manage(new Gtk::Grid);
+    search_group->set_column_spacing(5);
+    search_group->set_orientation(Gtk::ORIENTATION_HORIZONTAL);
+    search_group->set_valign(Gtk::ALIGN_CENTER);
+    search_group->attach(m_search_button, 0, 0, 1, 1);
+    search_group->show_all();
+    right_box->attach(*search_group, right_box_pos++, 0, 1, 1);
 
     m_window_actions_button = manage(new Gtk::Button);
     m_window_actions_button->set_image_from_icon_name(MAIN_MENU_PRIMARY_ICON);
@@ -282,6 +296,8 @@ namespace gnote {
       sigc::mem_fun(*this, &NoteRecentChanges::on_show_window_menu));
     m_window_actions_button->add_accelerator(
       "activate", m_accel_group, GDK_KEY_F10, (Gdk::ModifierType) 0, (Gtk::AccelFlags) 0);
+    m_window_actions_button->add_accelerator(
+      "activate", m_accel_group, GDK_KEY_comma, Gdk::CONTROL_MASK, (Gtk::AccelFlags) 0);
     m_window_actions_button->show_all();
     right_box->attach(*m_window_actions_button, right_box_pos++, 0, 1, 1);
     right_box->show();
@@ -338,9 +354,9 @@ namespace gnote {
     m_search_box->attach(*m_search_entry, 0, 0, 1, 1);
     m_search_box->set_halign(Gtk::ALIGN_CENTER);
 
-    auto content = dynamic_cast<Gtk::Grid*>(m_embed_book.get_parent());
+    auto content = dynamic_cast<Gtk::Grid*>(m_search_button.get_parent());
     if(content) {
-      content->attach_next_to(*m_search_box, m_embed_book, Gtk::POS_TOP);
+      content->attach_next_to(*m_search_box, m_search_button, Gtk::POS_LEFT);
     }
     else {
       ERR_OUT(_("Parent of embed box is not a Gtk::Grid, please report a bug!"));
@@ -612,6 +628,25 @@ namespace gnote {
     return true;
   }
 
+  void NoteRecentChanges::next_tab()
+  {
+    int next_page = 1 + m_embed_book.get_current_page();
+    if(next_page >= m_embed_book.get_n_pages()) {
+      next_page = 0;
+    }
+
+    m_embed_book.set_current_page(next_page);
+  }
+
+  void NoteRecentChanges::previous_tab()
+  {
+    int prev_page = m_embed_book.get_current_page() - 1;
+    if(prev_page < 0) {
+      prev_page = m_embed_book.get_n_pages() - 1;
+    }
+
+    m_embed_book.set_current_page(prev_page);
+  }
 
   void NoteRecentChanges::on_show()
   {
@@ -620,17 +655,17 @@ namespace gnote {
     MainWindow::on_show();
   }
 
-  void NoteRecentChanges::set_search_text(const Glib::ustring & value)
+  void NoteRecentChanges::set_search_text(Glib::ustring && value)
   {
     if(m_search_box) {
-      m_search_entry->set_text(value);
+      m_search_entry->set_text(std::move(value));
     }
     else {
       if(!m_search_text) {
-        m_search_text = new Glib::ustring(value);
+        m_search_text = new Glib::ustring(std::move(value));
       }
       else {
-        *m_search_text = value;
+        *m_search_text = std::move(value);
       }
     }
   }
@@ -970,9 +1005,25 @@ namespace gnote {
     menu->set_relative_to(*button);
     menu->set_modal(true);
     menu->set_position(Gtk::POS_BOTTOM);
+
+    menu->signal_closed().connect(sigc::mem_fun(*this, &NoteRecentChanges::on_window_menu_closed));
     return menu;
   }
 
+  void NoteRecentChanges::on_window_menu_closed()
+  {
+    auto idx = m_embed_book.get_current_page();
+    if(idx < 0) {
+      return;
+    }
+    auto current_page = dynamic_cast<EmbeddableWidget*>(m_embed_book.get_nth_page(idx));
+    if(current_page == nullptr) {
+      return;
+    }
+
+    current_page->set_initial_focus();
+  }
+
   void NoteRecentChanges::on_popover_widgets_changed()
   {
     if(m_window_menu_embedded) {
