@@ -110,7 +110,6 @@ SearchNotesWidget::SearchNotesWidget(IGnote & g, NoteManagerBase & m)
   notebook_manager.signal_note_pin_status_changed
     .connect(sigc::mem_fun(*this, &SearchNotesWidget::on_note_pin_status_changed));
 
-  g.preferences().signal_open_notes_in_new_window_changed.connect(sigc::mem_fun(*this, &SearchNotesWidget::on_settings_changed));
   parse_sorting_setting(g.preferences().search_sorting());
   g.preferences().signal_desktop_gnome_clock_format_changed.connect(sigc::mem_fun(*this, &SearchNotesWidget::update_results));
 }
@@ -131,8 +130,7 @@ SearchNotesWidget::~SearchNotesWidget()
 Glib::ustring SearchNotesWidget::get_name() const
 {
   notebooks::Notebook::Ptr selected_notebook = get_selected_notebook();
-  if(!selected_notebook
-     || std::dynamic_pointer_cast<notebooks::AllNotesNotebook>(selected_notebook)) {
+  if(!selected_notebook) {
     return "";
   }
   return selected_notebook->get_name();
@@ -1301,11 +1299,9 @@ Gtk::Menu *SearchNotesWidget::get_note_list_context_menu()
     m_note_list_context_menu = new Gtk::Menu;
 
     Gtk::MenuItem *item;
-    if(!m_gnote.preferences().open_notes_in_new_window()) {
-      m_open_note_menu_item = manage(new Gtk::MenuItem(_("_Open"), true));
-      m_open_note_menu_item->signal_activate().connect(sigc::mem_fun(*this, &SearchNotesWidget::on_open_note));
-      m_note_list_context_menu->add(*m_open_note_menu_item);
-    }
+    m_open_note_menu_item = manage(new Gtk::MenuItem(_("_Open"), true));
+    m_open_note_menu_item->signal_activate().connect(sigc::mem_fun(*this, &SearchNotesWidget::on_open_note));
+    m_note_list_context_menu->add(*m_open_note_menu_item);
 
     m_open_note_new_window_menu_item = manage(new Gtk::MenuItem(_("Open In New _Window"), true));
     m_open_note_new_window_menu_item->signal_activate()
@@ -1407,18 +1403,12 @@ void SearchNotesWidget::foreground()
 
   m_open_note_accel = win->keybinder().add_accelerator(sigc::mem_fun(*this, &SearchNotesWidget::on_open_note), GDK_KEY_O, Gdk::CONTROL_MASK, Gtk::ACCEL_VISIBLE);
   m_open_note_new_window_accel = win->keybinder().add_accelerator(sigc::mem_fun(*this, &SearchNotesWidget::on_open_note_new_window), GDK_KEY_W, Gdk::MOD1_MASK, Gtk::ACCEL_VISIBLE);
-  auto & manager(m_gnote.action_manager());
-  register_callbacks();
-  m_callback_changed_cid = manager.signal_main_window_search_actions_changed
-    .connect(sigc::mem_fun(*this, &SearchNotesWidget::callbacks_changed));
 }
 
 void SearchNotesWidget::background()
 {
   EmbeddableWidget::background();
   save_position();
-  unregister_callbacks();
-  m_callback_changed_cid.disconnect();
   MainWindow *win = dynamic_cast<MainWindow*>(host());
   if(!win) {
     return;
@@ -1429,12 +1419,6 @@ void SearchNotesWidget::background()
   m_open_note_new_window_accel = nullptr;
 }
 
-void SearchNotesWidget::hint_size(int & width, int & height)
-{
-  width = m_gnote.preferences().search_window_width();
-  height = m_gnote.preferences().search_window_height();
-}
-
 void SearchNotesWidget::size_internals()
 {
   int pos = m_gnote.preferences().search_window_splitter_pos();
@@ -1451,28 +1435,6 @@ void SearchNotesWidget::set_initial_focus()
   }
 }
 
-std::vector<PopoverWidget> SearchNotesWidget::get_popover_widgets()
-{
-  std::vector<PopoverWidget> popover_widgets;
-  popover_widgets.reserve(20);
-  m_gnote.action_manager().signal_build_main_window_search_popover(popover_widgets);
-  for(unsigned i = 0; i < popover_widgets.size(); ++i) {
-    popover_widgets[i].secondary_order = i;
-  }
-  return popover_widgets;
-}
-
-void SearchNotesWidget::on_settings_changed()
-{
-  if(m_note_list_context_menu) {
-    delete m_note_list_context_menu;
-    m_note_list_context_menu = NULL;
-    m_open_note_menu_item = nullptr;
-    m_open_note_new_window_menu_item = nullptr;
-    m_delete_note_menu_item = nullptr;
-  }
-}
-
 void SearchNotesWidget::on_sorting_changed()
 {
   // don't do anything if in search mode
@@ -1554,35 +1516,4 @@ void SearchNotesWidget::on_rename_notebook()
   m_notebooksTree->set_cursor(selected_row[0], *m_notebooksTree->get_column(0), true);
 }
 
-void SearchNotesWidget::callbacks_changed()
-{
-  unregister_callbacks();
-  register_callbacks();
-  signal_popover_widgets_changed();
-}
-
-void SearchNotesWidget::register_callbacks()
-{
-  MainWindow *win = dynamic_cast<MainWindow*>(host());
-  if(!win) {
-    return;
-  }
-  auto & manager(m_gnote.action_manager());
-  auto cbacks = manager.get_main_window_search_callbacks();
-  for(auto & cback : cbacks) {
-    auto action = win->find_action(cback.first);
-    if(action) {
-      m_action_cids.push_back(action->signal_activate().connect(cback.second));
-    }
-  }
-}
-
-void SearchNotesWidget::unregister_callbacks()
-{
-  for(auto & cid : m_action_cids) {
-    cid.disconnect();
-  }
-  m_action_cids.clear();
-}
-
 }
