@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2017 Aurimas Cernius
+ * Copyright (C) 2017-2019 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a
@@ -28,6 +28,7 @@
 
 #include <vector>
 
+#include <giomm/file.h>
 #include <glibmm/ustring.h>
 
 namespace sharp {
@@ -41,10 +42,12 @@ namespace sharp {
   Glib::ustring file_dirname(const Glib::ustring & p);
   /** return the filename from the file path */
   Glib::ustring file_filename(const Glib::ustring & p);
+  Glib::ustring file_filename(const Glib::RefPtr<Gio::File> & p);
   void file_copy(const Glib::ustring & source, const Glib::ustring & dest);
 
   std::vector<Glib::ustring> file_read_all_lines(const Glib::ustring & path);
   Glib::ustring file_read_all_text(const Glib::ustring & path);
+  Glib::ustring file_read_all_text(const Glib::RefPtr<Gio::File> & path);
   void file_write_all_text(const Glib::ustring & path, const Glib::ustring & content);
 }
 
