@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011,2013,2017,2019 Aurimas Cernius
+ * Copyright (C) 2011,2013,2017,2019-2020 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a
@@ -38,28 +38,33 @@
 
 namespace sharp {
 
+  template <typename GetterT, typename SetterT>
   class PropertyEditorBase
   {
   public:
-    virtual ~PropertyEditorBase();
+    virtual ~PropertyEditorBase() = default;
     virtual void setup() = 0;
 
   protected:
-    PropertyEditorBase(Glib::RefPtr<Gio::Settings> & settings, const char *key, Gtk::Widget &w);
+    PropertyEditorBase(GetterT && getter, SetterT && setter, Gtk::Widget & w);
 
-    Glib::ustring m_key;
     Gtk::Widget &m_widget;
     sigc::connection m_connection;
-    Glib::RefPtr<Gio::Settings> m_settings;
+    GetterT m_getter;
+    SetterT m_setter;
   private:
     void static destroy_notify(gpointer data);
   };
 
+
+  typedef std::function<Glib::ustring()> StringPropertyGetterT;
+  typedef std::function<void(const Glib::ustring&)> StringPropertySetterT;
+
   class PropertyEditor
-      : public PropertyEditorBase
+      : public PropertyEditorBase<StringPropertyGetterT, StringPropertySetterT>
   {
   public:
-    PropertyEditor(Glib::RefPtr<Gio::Settings> & settings, const char * key, Gtk::Entry &entry);
+    PropertyEditor(StringPropertyGetterT && getter, StringPropertySetterT && setter, Gtk::Entry &entry);
 
     virtual void setup() override;
 
@@ -67,11 +72,15 @@ namespace sharp {
     void on_changed();
   };
 
+
+  typedef std::function<bool()> BoolPropertyGetterT;
+  typedef std::function<void(bool)> BoolPropertySetterT;
+
   class PropertyEditorBool
-    : public PropertyEditorBase
+    : public PropertyEditorBase<BoolPropertyGetterT, BoolPropertySetterT>
   {
   public:
-    PropertyEditorBool(Glib::RefPtr<Gio::Settings> & settings, const char * key, Gtk::ToggleButton &button);
+    PropertyEditorBool(BoolPropertyGetterT && getter, BoolPropertySetterT && setter, Gtk::ToggleButton &button);
     void add_guard(Gtk::Widget* w)
       {
         m_guarded.push_back(w);
