@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2012-2013,2017 Aurimas Cernius
+ * Copyright (C) 2012-2013,2017,2019-2020 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,6 +18,7 @@
  */
 
 
+#include "ignote.hpp"
 #include "isyncmanager.hpp"
 #include "preferences.hpp"
 #include "sharp/uuid.hpp"
@@ -27,27 +28,18 @@ namespace gnote {
 namespace sync {
 
 
-SyncLockInfo::SyncLockInfo()
-  : client_id(Preferences::obj().get_schema_settings(Preferences::SCHEMA_SYNC)->get_string(Preferences::SYNC_CLIENT_ID))
-  , transaction_id(sharp::uuid().string())
-  , renew_count(0)
-  , duration(0, 2, 0) // default of 2 minutes
-  , revision(0)
-{
-}
-
 SyncLockInfo::SyncLockInfo(const Glib::ustring & client)
   : client_id(client)
   , transaction_id(sharp::uuid().string())
   , renew_count(0)
-  , duration(0, 2, 0) // default of 2 minutes
+  , duration(sharp::time_span(0, 2, 0)) // default of 2 minutes
   , revision(0)
 {
 }
 
 Glib::ustring SyncLockInfo::hash_string()
 {
-  return Glib::ustring::compose("%1-%2-%3-%4-%5", transaction_id, client_id, renew_count, duration.string(), revision);
+  return Glib::ustring::compose("%1-%2-%3-%4-%5", transaction_id, client_id, renew_count, sharp::time_span_string(duration), revision);
 }
 
 
