@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2012-2014,2017-2020 Aurimas Cernius
+ * Copyright (C) 2012-2014,2017-2021 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,9 +23,9 @@
 
 
 #include <map>
+#include <thread>
 
 #include <glibmm/main.h>
-#include <glibmm/thread.h>
 
 #include "isyncmanager.hpp"
 
@@ -53,10 +53,6 @@ namespace sync {
       {
         return m_state;
       }
-    virtual SyncUtils & utils() override
-      {
-        return m_utils;
-      }
   protected:
     virtual void initialize_sync_service_addins(NoteManagerBase &);
     virtual void connect_system_signals();
@@ -77,7 +73,6 @@ namespace sync {
   private:
     void handle_note_saved_or_deleted(const NoteBase::Ptr & note);
     void handle_note_buffer_changed(const NoteBase::Ptr & note);
-    void preferences_setting_changed(const Glib::ustring & key);
     void update_sync_action();
     void background_sync_checker();
     void set_state(SyncState new_state);
@@ -87,11 +82,10 @@ namespace sync {
     void get_synchronized_xml_bits(const Glib::ustring & noteXml, Glib::ustring & title, Glib::ustring & tags, Glib::ustring & content);
     void abort_sync(SyncServer *server);
 
-    SyncUtils m_utils;
     IGnote & m_gnote;
     NoteManagerBase & m_note_manager;
     SyncState m_state;
-    Glib::Thread *m_sync_thread;
+    std::thread *m_sync_thread;
     SyncTitleConflictResolution m_conflict_resolution;
     utils::InterruptableTimeout m_autosync_timer;
     int m_autosync_timeout_pref_minutes;
