@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2015,2017,2019-2021 Aurimas Cernius
+ * Copyright (C) 2010-2015,2017,2019-2023 Aurimas Cernius
  * Copyright (C) 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -184,7 +184,7 @@ namespace gnote {
     }
     // Only set window title here, to give feedback that we
     // are indeed changing the title.
-    get_window()->set_name(title);
+    get_window()->set_name(std::move(title));
   }
 
 
@@ -215,7 +215,7 @@ namespace gnote {
     }
 
     DBG_OUT ("Renaming note from %s to %s", get_note()->get_title().c_str(), title.c_str());
-    get_note()->set_title(title, true);
+    get_note()->set_title(std::move(title), true);
     return true;
   }
 
@@ -612,6 +612,9 @@ namespace gnote {
     catch (Glib::Error & e) {
       utils::show_opening_location_error (get_host_window(), url, e.what());
     }
+    catch(const std::exception & e) {
+      ERR_OUT("Failed to open URL: %s", e.what());
+    }
 
     // Kill the middle button paste...
     return true;
@@ -726,12 +729,17 @@ namespace gnote {
 
   void NoteUrlWatcher::open_link_activate()
   {
-    Gtk::TextIter click_iter = get_buffer()->get_iter_at_mark (m_click_mark);
+    try {
+      Gtk::TextIter click_iter = get_buffer()->get_iter_at_mark (m_click_mark);
 
-    Gtk::TextIter start, end;
-    m_url_tag->get_extents (click_iter, start, end);
+      Gtk::TextIter start, end;
+      m_url_tag->get_extents (click_iter, start, end);
 
-    on_url_tag_activated(*(NoteEditor*)get_window()->editor(), start, end);
+      on_url_tag_activated(*(NoteEditor*)get_window()->editor(), start, end);
+    }
+    catch(const std::exception & e) {
+      ERR_OUT("Failed to open link: %s", e.what());
+    }
   }
 
 
@@ -880,10 +888,11 @@ namespace gnote {
       if (idx < 0)
         break;
 
-      TrieHit<NoteBase::WeakPtr> hit(idx, idx + find_title_lower.length(), find_title_lower, find_note);
+      auto title_len = find_title_lower.length();
+      TrieHit<NoteBase::WeakPtr> hit(idx, idx + title_len, Glib::ustring(find_title_lower), find_note);
       do_highlight(note_manager, note, hit, start, end);
 
-      idx += find_title_lower.length();
+      idx += title_len;
     }
   }
 
@@ -1065,7 +1074,7 @@ namespace gnote {
     if (!link) {
       DBG_OUT("Creating note '%s'...", link_name.c_str());
       try {
-        link = manager().create (link_name);
+        link = manager().create(Glib::ustring(link_name));
       } 
       catch(...)
       {
